@@ -21,7 +21,7 @@ from lapels import regionutils
 
 from lapels.utils import log
 
-VERSION = '0.0.6'
+VERSION = '0.1.0'
 TESTING = False  # For unit test: return the annotated read data once set to 1.
 VERBOSITY = 0    # Print out detail log during the process.
 
@@ -61,7 +61,7 @@ def getReadOffset(rseq, pos):
             else:
                 offset += length              # (b) pos not in this match
                 curPos += length
-        elif op == 1:                         # Insertion
+        elif op == 1 or op == 4:              # Insertion and Soft Clipping
             offset += length
         elif op == 2 or op == 3:              # Deletion or Splicing junction
             curPos += length
@@ -91,7 +91,7 @@ def getTargetRegions(rseq):
             assert length > 0
             ret.append((op, None, newpos, newpos + length - 1))
             newpos += length
-        elif op == 1:                      # Insertion(I1)
+        elif op == 1 or op == 4:           # Insertion(I1) and Soft Clipping
             ret.append((op, None, newpos, newpos - 1))
         elif op == 2 or op == 3:           # Deletion(D_1)/Splice junction(N_1)
             ret.append((op, None, newpos, newpos + length - 1))
@@ -159,7 +159,7 @@ class Annotator:
         tstart = region[2]
         tend = region[3]
         if tstart > tend:
-            assert op == 1  # It must be an insertion region(I_1)
+            assert (op == 1 or op == 4) # It must be an insertion region(I_1)
             return (op,)
 
         # Find the region's fuzzy boundaries in the reference coordinate.
